==> gbsite-1.0.0.tar.gz: gbsite/htdocs/tools/admin/projapprove.php <==
<html>
<head>
<title>Project Approve form</title>
</head>
<body bgcolor=white>
<?
    $project_id = $QUERY_STRING;

    $query = "select project_id, member.member_id, project_title, approved, project_name, member_name ".
             "  from project, member where project_id = $project_id and project.member_id = member.member_id";
    $res = pg_exec($conn,$query);

    if(pg_numrows($res) < 1) {
        echo "No project could be found by project_id of $project_id<br>\n";
    } else {
        $project_id = pg_result($res,0,0);
        $member_id = pg_result($res,0,1);
        $project_title = pg_result($res,0,2);
        $approved = pg_result($res,0,3);
        $project_name = pg_result($res,0,4);
        $member_name = pg_result($res,0,5);

        if($approved != "") {
            echo "This project has already been " . ($approved=="t"?"Approved":"Declined") . ".<br>\n";
        } else {
            $query = "select member_name, email from member where member_id = $member_id";
            $res   = pg_exec($conn,$query);
            if(pg_numrows($res) < 1) {
                echo "the member of id $member_id who created this project doesn't appear to exist.<br>\n";
            } else {
                $member_name = pg_result($res,0,0);
                $member_email = pg_result($res,0,1);

                $query = "update project set approved = true where project_id = $project_id";
                $res   = pg_exec($conn,$query);

                # the password we will be using to create the mailing lists
                $list_password = substr(md5(time()),0,8);

                mail($member_email, "GreatBridge.org project approval for $project_name",
                    "Dear $member_name,

Thanks for submitting your $project_name project to the GreatBridge.org open source project site.

We're happy to approve your project.  You can start getting things set up at:

http://www.$HTTP_HOST/project/$project_name/projdisplay.php

In addition we have added $project_name-bugs, $project_name-patches and $project_name-news mailing lists to you project. You will be receiving an email for each of the lists as they are created with the password for those lists. The default password being assigned to the lists are $list_password. You can change this once the lists have been created by loggin into the mail list admin screens.

Thanks very much for your work on this project!

The GreatBridge.org team","From:webmaster@greatbridge.org");

                echo "project approved and email sent<br>\n";

                echo "running cvsnewproj<br>\n";
                system("/usr/local/cvsroot/bin/cvsnewproj $project_name");

                echo "adding user $member_name to cvs-writers file<br>\n";
                system("echo $member_name > /usr/local/cvsroot/$project_name/CVSROOT/writers; echo >> /usr/local/cvsroot/$project_name/CVSROOT/writers");

                $data = "$project_name-bugs $member_email $list_password";
                system("echo $data >> /home/mailman/pending_lists");
                echo "Adding $project_name-bugs maillist to be created.<br>";
                $data = "$project_name-patches $member_email $list_password";
                system("echo $data >> /home/mailman/pending_lists");
                echo "Adding $project_name-patches maillist to be created.<br>";
                $data = "$project_name-news $member_email $list_password";
                system("echo $data >> /home/mailman/pending_lists");
                echo "Adding $project_name-news maillist to be created.<br>";

            }
        }
    }
 ?>
</body>
</form>

==> gbsite-2.0.0.tar.gz: gbsite/htdocs/tools/admin/projapprove.php <==
<html>
<head>
<title>Project Approve form</title>
</head>
<body bgcolor=white>
<?
    $project_id = $QUERY_STRING;

    $query = "select project_id, member.member_id, project_title, approved, project_name, member_name ".
             "  from project, member where project_id = $project_id and project.member_id = member.member_id";
    $res = pg_exec($conn,$query);

    if(pg_numrows($res) < 1) {
        echo "No project could be found by project_id of $project_id<br>\n";
    } else {
        $project_id = pg_result($res,0,0);
        $member_id = pg_result($res,0,1);
        $project_title = pg_result($res,0,2);
        $approved = pg_result($res,0,3);
        $project_name = pg_result($res,0,4);
        $member_name = pg_result($res,0,5);

        if($approved != "") {
            echo "This project has already been " . ($approved=="t"?"Approved":"Declined") . ".<br>\n";
        } else {
            $query = "select member_name, email from member where member_id = $member_id";
            $res   = pg_exec($conn,$query);
            if(pg_numrows($res) < 1) {
                echo "the member of id $member_id who created this project doesn't appear to exist.<br>\n";
            } else {
                $member_name = pg_result($res,0,0);
                $member_email = pg_result($res,0,1);

                $query = "update project set approved = true where project_id = $project_id";
                $res   = pg_exec($conn,$query);

                # the password we will be using to create the mailing lists
                $list_password = substr(md5(time()),0,8);

                mail($member_email, "GreatBridge.org project approval for $project_name",
                    "Dear $member_name,

Thanks for submitting your $project_name project to the GreatBridge.org open source project site.

We're happy to approve your project.  You can start getting things set up at:

http://www.$HTTP_HOST/project/$project_name/projdisplay.php

In addition we have added $project_name-bugs, $project_name-patches and $project_name-news mailing lists to you project. You will be receiving an email for each of the lists as they are created with the password for those lists. The default password being assigned to the lists are $list_password. You can change this once the lists have been created by loggin into the mail list admin screens.

Thanks very much for your work on this project!

The GreatBridge.org team","From:webmaster@greatbridge.org");

                echo "project approved and email sent<br>\n";

                echo "running cvsnewproj<br>\n";
                system("/usr/local/cvsroot/bin/cvsnewproj $project_name");

                echo "adding user $member_name to cvs-writers file<br>\n";
                system("echo $member_name > /usr/local/cvsroot/$project_name/CVSROOT/writers; echo >> /usr/local/cvsroot/$project_name/CVSROOT/writers");

                $data = "$project_name-general $member_email $list_password";
                system("echo $data >> /home/mailman/pending_lists");
                echo "Adding $project_name-general maillist to be created.<br>";

                echo "Creating project directory on ftp site.<br>";
                system("mkdir $DOWNLOAD_FILE_PATH/$project_name");
                system("mkdir $DOWNLOAD_FILE_PATH/$project_name/incoming");
                system("chmod 775 $DOWNLOAD_FILE_PATH/$project_name/incoming");
            }
        }
    }
 ?>
</body>
</form>
